14.38. cdist-type__dot_file(7) — cdist 4.8.1 documentation

# 14.38. cdist-type__dot_file(7)

## 14.38.1. NAME

cdist-type__dot_file - install file under user's home directory

## 14.38.2. DESCRIPTION

This type installs a file (=__object_id) under user's home directory, providing a way to install per-user configuration files. File owner and group is deduced from user, for who file is installed.

Unlike regular __file type, you do not need make any assumptions, where user's home directory is.

## 14.38.3. REQUIRED PARAMETERS

user
  User, for who file is installed

## 14.38.4. OPTIONAL PARAMETERS

mode
  forwarded to __file type
state
  forwarded to __file type
source
  forwarded to __file type

## 14.38.5. MESSAGES

This type inherits all messages from file type, and do not add any new.

## 14.38.6. EXAMPLES

    # Install .forward file for user 'alice'. Since state is 'present',
    # user is not meant to edit this file, all changes will be overridden.
    # It is good idea to put warning about it in file itself.
    __dot_file .forward --user alice --source "$__files/forward"

    # Install .muttrc for user 'bob', if not already present. User can safely
    # edit it, his changes will not be overwritten.
    __dot_file .muttrc --user bob --source "$__files/recommended_mutt_config" --state exists

    # Install default xmonad config for user 'eve'. Parent directory is created automatically.
    __dot_file .xmonad/xmonad.hs --user eve --state exists --source "$__files/xmonad.hs"

## 14.38.7. SEE ALSO

cdist-type__file(7)

## 14.38.8. COPYING

Copyright (C) 2015 Dmitry Bogatov. Free use of this software is granted under the terms of the GNU General Public License version 3 or later (GPLv3+).